import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixSocialGroupsV2JoinGroupRequest from './social-groups-v2-join-group-request-join-group-requests.http.js';
// @ts-ignore
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var RequestStatus;
(function (RequestStatus) {
    /** Pending group request. */
    RequestStatus["PENDING"] = "PENDING";
    /** Approved group request. */
    RequestStatus["APPROVED"] = "APPROVED";
    /** Rejected group request. */
    RequestStatus["REJECTED"] = "REJECTED";
    /** Canceled group request. */
    RequestStatus["CANCELED"] = "CANCELED";
})(RequestStatus || (RequestStatus = {}));
export var ViolationType;
(function (ViolationType) {
    ViolationType["NONE"] = "NONE";
    ViolationType["NOT_LOGGED_IN"] = "NOT_LOGGED_IN";
    ViolationType["ALREADY_JOINED"] = "ALREADY_JOINED";
    ViolationType["SECRET_GROUP"] = "SECRET_GROUP";
    ViolationType["EVENTS"] = "EVENTS";
    ViolationType["PRICING_PlANS"] = "PRICING_PlANS";
    ViolationType["MEMBERSHIP_QUESTIONS"] = "MEMBERSHIP_QUESTIONS";
    ViolationType["ADMIN_APPROVAL"] = "ADMIN_APPROVAL";
})(ViolationType || (ViolationType = {}));
export var ItemsToUpdate;
(function (ItemsToUpdate) {
    /** Take into account only items which are listed in the request. */
    ItemsToUpdate["BY_ID"] = "BY_ID";
    /** Update all items. */
    ItemsToUpdate["ALL_ITEMS"] = "ALL_ITEMS";
})(ItemsToUpdate || (ItemsToUpdate = {}));
export var OwnershipFilter;
(function (OwnershipFilter) {
    /** All items. */
    OwnershipFilter["ALL"] = "ALL";
    /** Items for the current site member. */
    OwnershipFilter["CURRENT_MEMBER"] = "CURRENT_MEMBER";
})(OwnershipFilter || (OwnershipFilter = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Approves pending join group requests.
 * Group managers always have access to this functionality. In some cases, site owners will allow group members to use this functionality as well.
 * @param memberIds - IDs of the site members to approve.
 * @public
 * @requiredField groupId
 * @requiredField memberIds
 * @param groupId - ID of the group requested to join.
 * @fqn wix.social.groups.api.v2.JoinGroupRequestsService.ApproveJoinGroupRequests
 */
export async function approveJoinGroupRequests(groupId, memberIds) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        groupId: groupId,
        memberIds: memberIds,
    });
    const reqOpts = ambassadorWixSocialGroupsV2JoinGroupRequest.approveJoinGroupRequests(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]', memberIds: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['groupId', 'memberIds']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Rejects pending join group requests.
 * Group managers always have access to this functionality. In some cases, site owners will allow group members to use this functionality as well.
 * @param rejections - Rejection info.
 * @public
 * @requiredField groupId
 * @requiredField rejections
 * @param groupId - ID of the group requested to join.
 * @fqn wix.social.groups.api.v2.JoinGroupRequestsService.RejectJoinGroupRequests
 */
export async function rejectJoinGroupRequests(groupId, rejections) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        groupId: groupId,
        rejections: rejections,
    });
    const reqOpts = ambassadorWixSocialGroupsV2JoinGroupRequest.rejectJoinGroupRequests(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]', rejections: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['groupId', 'rejections']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Lists requests to join a group.
 *
 * > **Note:** This function is only relevant for private groups.
 *
 * The `listjoinGroupRequests()` function returns a Promise that resolves to a list of up to 100 requests to join a group. Sorts by default to `_createdDate` in descending order.
 * Only group admins can see requests to join their group. Site members can access their own join requests in their site.
 *
 * > **Notes:**
 * <!-- > + If the `suppressAuth` option is set to `true`, all permissions are overwritten, and all site members (including non-group members) can see requests to join a group. -->
 * @public
 * @requiredField groupId
 * @param groupId - ID of the group requested to join.
 * @fqn wix.social.groups.api.v2.JoinGroupRequestsService.ListJoinGroupRequests
 */
export async function listJoinGroupRequests(groupId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        groupId: groupId,
        limit: options?.limit,
        offset: options?.offset,
    });
    const reqOpts = ambassadorWixSocialGroupsV2JoinGroupRequest.listJoinGroupRequests(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                groupId: '$[0]',
                limit: '$[1].limit',
                offset: '$[1].offset',
            },
            singleArgumentUnchanged: false,
        }, ['groupId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates a query to retrieve a list of join requests.
 *
 * > **Notes:**
 * > + This function is only relevant for private groups.
 * > + For `SECRET` groups, only group admins can query requests to join their group. <!-- However, if the `suppressAuth` option is set to `true`, all permissions are overwritten, and all site members (including non-group members) can query requests to join a group. -->
 *
 * The `queryjoinGroupRequests()` function builds a query to retrieve a list of all requests to join a group, and returns a `JoinGroupRequestsQueryBuilder` object.
 *
 * The returned object contains the query definition which is typically used to run the query using the [`find()`](/join-group-requests-query-builder/find) function.
 *
 * You can refine the query by chaining `joinGroupRequestsQueryBuilder` functions onto the query. `joinGroupRequestsQueryBuilder` functions enable you to sort, filter, and control the results that `queryjoinGroupRequests()` returns.
 *
 * The results of the `queryjoinGroupRequests()` function are sorted by `_createdDate` in descending order.
 *
 * `queryjoinGroupRequests()` runs with this `joinGroupRequestsQueryBuilder` default, which you can override:
 * + [`limit(100)`](/join-group-requests-query-builder/limit)
 *
 * The following `joinGroupRequestsQueryBuilder` functions are supported for `queryjoinGroupRequests()`. For a full description of the joinGroupRequests object, see the object returned for the [`items`](/join-group-requests-query-result/items) property in `JoinGroupRequestsQueryResult`.
 *
 * @public
 * @requiredField groupId
 * @param groupId - Group ID.
 * @fqn wix.social.groups.api.v2.JoinGroupRequestsService.QueryJoinGroupRequests
 */
export function queryJoinGroupRequests(groupId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixSocialGroupsV2JoinGroupRequest.queryJoinGroupRequests({
                ...payload,
                ...(options ?? {}),
                groupId,
            });
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, groupId, options];
            return renameKeysFromSDKRequestToRESTRequest({
                groupId: args?.[1],
                ...args?.[2],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(transformPaths(data, []));
            return {
                items: transformedData?.joinGroupRequests,
                pagingMetadata: transformedData?.metadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { groupId: '$[1]', query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
//# sourceMappingURL=social-groups-v2-join-group-request-join-group-requests.universal.js.map