import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { ApproveJoinGroupRequestsResponse, JoinGroupRequestApprovedEnvelope, JoinGroupRequestCreatedEnvelope, JoinGroupRequestRejectedEnvelope, JoinGroupRequestsQueryBuilder, ListJoinGroupRequestsOptions, ListJoinGroupRequestsResponse, QueryJoinGroupRequestsOptions, RejectJoinGroupRequestsResponse, Rejection } from './social-groups-v2-join-group-request-join-group-requests.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function approveJoinGroupRequests(httpClient: HttpClient): ApproveJoinGroupRequestsSignature;
interface ApproveJoinGroupRequestsSignature {
    /**
     * Approves pending join group requests.
     * Group managers always have access to this functionality. In some cases, site owners will allow group members to use this functionality as well.
     * @param - IDs of the site members to approve.
     * @param - ID of the group requested to join.
     */
    (groupId: string, memberIds: string[]): Promise<ApproveJoinGroupRequestsResponse>;
}
export declare function rejectJoinGroupRequests(httpClient: HttpClient): RejectJoinGroupRequestsSignature;
interface RejectJoinGroupRequestsSignature {
    /**
     * Rejects pending join group requests.
     * Group managers always have access to this functionality. In some cases, site owners will allow group members to use this functionality as well.
     * @param - Rejection info.
     * @param - ID of the group requested to join.
     */
    (groupId: string, rejections: Rejection[]): Promise<RejectJoinGroupRequestsResponse>;
}
export declare function listJoinGroupRequests(httpClient: HttpClient): ListJoinGroupRequestsSignature;
interface ListJoinGroupRequestsSignature {
    /**
     * Lists requests to join a group.
     *
     * > **Note:** This function is only relevant for private groups.
     *
     * The `listjoinGroupRequests()` function returns a Promise that resolves to a list of up to 100 requests to join a group. Sorts by default to `_createdDate` in descending order.
     * Only group admins can see requests to join their group. Site members can access their own join requests in their site.
     *
     * > **Notes:**
     * <!-- > + If the `suppressAuth` option is set to `true`, all permissions are overwritten, and all site members (including non-group members) can see requests to join a group. -->
     * @param - ID of the group requested to join.
     */
    (groupId: string, options?: ListJoinGroupRequestsOptions | undefined): Promise<ListJoinGroupRequestsResponse>;
}
export declare function queryJoinGroupRequests(httpClient: HttpClient): QueryJoinGroupRequestsSignature;
interface QueryJoinGroupRequestsSignature {
    /**
     * Creates a query to retrieve a list of join requests.
     *
     * > **Notes:**
     * > + This function is only relevant for private groups.
     * > + For `SECRET` groups, only group admins can query requests to join their group. <!-- However, if the `suppressAuth` option is set to `true`, all permissions are overwritten, and all site members (including non-group members) can query requests to join a group. -->
     *
     * The `queryjoinGroupRequests()` function builds a query to retrieve a list of all requests to join a group, and returns a `JoinGroupRequestsQueryBuilder` object.
     *
     * The returned object contains the query definition which is typically used to run the query using the [`find()`](/join-group-requests-query-builder/find) function.
     *
     * You can refine the query by chaining `joinGroupRequestsQueryBuilder` functions onto the query. `joinGroupRequestsQueryBuilder` functions enable you to sort, filter, and control the results that `queryjoinGroupRequests()` returns.
     *
     * The results of the `queryjoinGroupRequests()` function are sorted by `_createdDate` in descending order.
     *
     * `queryjoinGroupRequests()` runs with this `joinGroupRequestsQueryBuilder` default, which you can override:
     * + [`limit(100)`](/join-group-requests-query-builder/limit)
     *
     * The following `joinGroupRequestsQueryBuilder` functions are supported for `queryjoinGroupRequests()`. For a full description of the joinGroupRequests object, see the object returned for the [`items`](/join-group-requests-query-result/items) property in `JoinGroupRequestsQueryResult`.
     *
     * @param - Group ID.
     */
    (groupId: string, options?: QueryJoinGroupRequestsOptions | undefined): JoinGroupRequestsQueryBuilder;
}
export declare const onJoinGroupRequestApproved: EventDefinition<JoinGroupRequestApprovedEnvelope, "wix.social_groups.v2.join_group_request_approved">;
export declare const onJoinGroupRequestCreated: EventDefinition<JoinGroupRequestCreatedEnvelope, "wix.social_groups.v2.join_group_request_created">;
export declare const onJoinGroupRequestRejected: EventDefinition<JoinGroupRequestRejectedEnvelope, "wix.social_groups.v2.join_group_request_rejected">;
export { ActionEvent, ApproveAllJoinGroupRequestsRequest, ApproveAllJoinGroupRequestsResponse, ApproveJoinGroupRequestsRequest, ApproveJoinGroupRequestsResponse, BaseEventMetadata, CancelJoinGroupRequestRequest, CancelJoinGroupRequestResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, EventsViolationOptions, GetJoinRequirementsRequest, GetJoinRequirementsResponse, IdentificationData, IdentificationDataIdOneOf, ItemsToUpdate, JoinGroupRequest, JoinGroupRequestApproved, JoinGroupRequestApprovedEnvelope, JoinGroupRequestCancelled, JoinGroupRequestCreatedEnvelope, JoinGroupRequestRejected, JoinGroupRequestRejectedEnvelope, JoinGroupRequestsQueryBuilder, JoinGroupRequestsQueryResult, JoinRequestsApproved, ListAllJoinGroupRequestsRequest, ListAllJoinGroupRequestsResponse, ListJoinGroupRequestsOptions, ListJoinGroupRequestsRequest, ListJoinGroupRequestsResponse, MemberJoinedGroup, MembersAddedToGroup, MembersInvitedToGroup, MembershipQuestionAnswer, MembershipQuestionViolationOptions, MessageEnvelope, OwnershipFilter, Paging, PagingMetadata, PaidPlan, PricingPlanViolationOptions, Query, QueryJoinGroupRequestsOptions, QueryJoinGroupRequestsRequest, QueryJoinGroupRequestsResponse, RejectAllJoinGroupRequestsRequest, RejectAllJoinGroupRequestsResponse, RejectJoinGroupRequestsRequest, RejectJoinGroupRequestsResponse, Rejection, RequestDetails, RequestStatus, RestoreInfo, SocialGroupsEvent, SocialGroupsEventPayloadOneOf, SortOrder, Sorting, SubmitJoinGroupRequestRequest, SubmitJoinGroupRequestResponse, Violation, ViolationType, ViolationViolationOptionsOneOf, WebhookIdentityType, } from './social-groups-v2-join-group-request-join-group-requests.universal.js';
